/**
 * @file main.c
 * 
 * Demonstration of bug in Doxygen for C99 designated Initializers
 ******************************************************************************/

/**
 * LowMemoryMap Structure.
 **************************************************************************************************/
typedef struct _LowMemLayout
{
	uchar Identifier;						///< Offset 0:	set to 6 for XFP or 11 for XFP-RF
	uchar SignalConditionerControl;			///< Offset 1:	@see section 5.3 of MSA XFP spec

	struct _Thresholds
	{
		signed short ModTempHighAlarm;		///< Module temp high threshold for Alarm, Address:2
		signed short ModTempLowAlarm;		///< Module temp low threshold for Alarm, Address:4
		signed short ModTempHighWarning;	///< Module temp high threshold for Warning, Address:6
		signed short ModTempLowWarning;		///< Module temp low threshold for Warning, Address:8

	} Thresholds;
	
	uchar PageSelectByte;
} LowMemoryMap;

/**
 * Default values for the common (lower memory) table. These are used to initialize the RAM image
 * at power up.
 *
 * Note: Using C99 designated initializers (check Wikipedia) to simplify this and to avoid having
 * to reorder everything if the structure changes order or sizes or whatever. Bizarrely, this
 * syntax is not available in C++ (yet).
 *****************************************************************************************************/
const LowMemoryMap LowMemoryDefault = {
	.Identifier						= 0xB,			///< Offset 0:	set to 11 for XFP-RF
	.SignalConditionerControl		= 0,			///< Offset 1:	@see section 5.3 of spec

	.Thresholds.ModTempHighAlarm	=  70 * 256,	///<  70	ModTempHighAlarm;
	.Thresholds.ModTempLowAlarm		= -20 * 256,	///< -20	ModTempLowAlarm;		
	.Thresholds.ModTempHighWarning	=  50 * 256,	///<  50	ModTempHighWarning;
	.Thresholds.ModTempLowWarning	=   0,			///<   0	ModTempLowWarning;
};

LowMemoryMap XFPLowMemory;

main(int argc, char *argv[])
{
	XFPLowMemory = LowMemoryDefault;

	exit(10);
}

